@@ -85,7 +85,7 @@ public:
     /**
      * Write the preferences to the configuration file
      */
-    void write();
+    void write( bool sync = true );
 
     /**
      * Read the profiles from the profiles file
@@ -206,23 +206,33 @@ public:
     /**
      * Returns true if the @p file can be added to the conversion list (can be decoded)
      */
-    bool acceptFile( const QString& mimeType );
+    bool acceptFile( const QString& format );
 
     /**
      * Returns true if the @p file can be added to the replay gain tool
      */
-    bool acceptReplayGainFile( const QString& mimeType );
+    bool acceptReplayGainFile( const QString& format );
 
     /**
      * Returns a file filter suitable for the file open dialog
      */
     QString fileFilter( bool wav = true );
 
+    /**
+     * Returns a string list of supported file formats
+     */
+    QStringList fileTypes( bool wav = true );
+
     /**
      * Returns a file filter suitable for the file open dialog for the replay gain scanner
      */
     QString replayGainFilter();
 
+    /**
+     * Returns a string list of Replay Gain supported file formats
+     */
+    QStringList replayGainFileTypes();
+
     struct Data {
         struct General {
             int startTab;
