@@ -65,7 +65,7 @@ ConfigPluginsPage::ConfigPluginsPage( Config* _config, QWidget* parent, const ch
     connect( pAboutPlugin, SIGNAL(clicked()),
                this, SLOT(aboutPlugin())
              );
-
+/* NOTE kaligames.de is down
     box->addSpacing( 5 );
 
     QLabel* lOnlinePluginsLabel = new QLabel( i18n("Available plugins")+":", parent, "lOnlinePluginsLabel" );
@@ -145,6 +145,7 @@ ConfigPluginsPage::ConfigPluginsPage( Config* _config, QWidget* parent, const ch
             file.close();
         }
     }
+*/
 }
 
 ConfigPluginsPage::~ConfigPluginsPage()
@@ -152,14 +153,14 @@ ConfigPluginsPage::~ConfigPluginsPage()
 
 void ConfigPluginsPage::resetDefaults()
 {
-    cCheckOnlinePlugins->setChecked( false );
+//     cCheckOnlinePlugins->setChecked( false );
 
-    cfgChanged();
+//     cfgChanged();
 }
 
 void ConfigPluginsPage::saveSettings()
 {
-    config->data.plugins.checkForUpdates = cCheckOnlinePlugins->isChecked();
+//     config->data.plugins.checkForUpdates = cCheckOnlinePlugins->isChecked();
 }
 
 void ConfigPluginsPage::pluginsSelectionChanged( int index )
