@@ -84,18 +84,30 @@ void Convert::get( ConvertItem* item )
     QString src = item->fileListItem->options.filePathName;
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting file")+"... 00 %" );
 
-//     KURL source( src );
-    KURL source;
-    source.setPath( src );
+    KURL source( src );
     KURL destination( item->tempInFile->name() );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::getCorrection( ConvertItem* item )
@@ -111,20 +123,32 @@ void Convert::getCorrection( ConvertItem* item )
         return;
     }
 
-//     KURL source( file.name() );
-    KURL source;
-    source.setPath( file.name() );
+    KURL source( file.name() );
     KURL destination( item->correctionInFile );
 
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting correction file")+"... 00 %" );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::rip( ConvertItem* item )
@@ -445,8 +469,9 @@ void Convert::encode( ConvertItem* item )
         param.append( " " + plugin->enc.replaygain.avoid );
     }
 
-    if( !tagEngine->canWrite(item->fileListItem->options.encodingOptions.sFormat) && item->fileListItem->tags && plugin->enc.tag.enabled ) {
-        if( plugin->enc.tag.param ) param.append( " " + plugin->enc.tag.param );
+//     if( !tagEngine->canWrite(item->fileListItem->options.encodingOptions.sFormat) && item->fileListItem->tags && plugin->enc.tag.enabled ) {
+    if( item->fileListItem->tags && plugin->enc.tag.enabled && item->fileListItem->options.encodingOptions.sFormat != "aac" ) { // HACK don't write metadata to aac
+        if( !plugin->enc.tag.param.isEmpty() ) param.append( " " + plugin->enc.tag.param );
         if( !plugin->enc.tag.artist.isEmpty() && !item->fileListItem->tags->artist.isEmpty() ) param.append( " " + plugin->enc.tag.artist );
         if( !plugin->enc.tag.album.isEmpty() && !item->fileListItem->tags->album.isEmpty() ) param.append( " " + plugin->enc.tag.album );
         if( !plugin->enc.tag.comment.isEmpty() && !item->fileListItem->tags->comment.isEmpty() ) param.append( " " + plugin->enc.tag.comment );
@@ -507,14 +532,14 @@ void Convert::encode( ConvertItem* item )
     param.replace( "%s", sSamplingRate );
 
     if( item->fileListItem->tags ) {
-        param.replace( "%ta", item->fileListItem->tags->artist );
-        param.replace( "%tb", item->fileListItem->tags->album );
-        param.replace( "%tc", item->fileListItem->tags->comment );
+        param.replace( "%ta", "\""+item->fileListItem->tags->artist+"\"" );
+        param.replace( "%tb", "\""+item->fileListItem->tags->album+"\"" );
+        param.replace( "%tc", "\""+item->fileListItem->tags->comment+"\"" );
         param.replace( "%td", QString::number(item->fileListItem->tags->disc) );
-        param.replace( "%tg", item->fileListItem->tags->genre );
+        param.replace( "%tg", "\""+item->fileListItem->tags->genre+"\"" );
         param.replace( "%tn", QString::number(item->fileListItem->tags->track) );
-        param.replace( "%tp", item->fileListItem->tags->composer );
-        param.replace( "%tt", item->fileListItem->tags->title );
+        param.replace( "%tp", "\""+item->fileListItem->tags->composer+"\"" );
+        param.replace( "%tt", "\""+item->fileListItem->tags->title+"\"" );
         param.replace( "%ty", QString::number(item->fileListItem->tags->year) );
     }
 
@@ -592,17 +617,29 @@ void Convert::put( ConvertItem* item )
     item->outputFilePathName = OutputDirectory::makePath( OutputDirectory::calcPath(item->fileListItem,config) );
 
     KURL source( src );
-//     KURL destination( item->outputFilePathName );
-    KURL destination;
-    destination.setPath( item->outputFilePathName );
+    KURL destination( item->outputFilePathName );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::putCorrection( ConvertItem* item )
@@ -621,13 +658,27 @@ void Convert::putCorrection( ConvertItem* item )
 
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Moving correction file")+"... 00 %" );
 
-    item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-    connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
-               this, SLOT(moveProgress(KIO::Job*,unsigned long))
-             );
-    connect( item->moveJob, SIGNAL(result(KIO::Job*)),
-               this, SLOT(moveFinished(KIO::Job*))
-             );
+    if( source.isLocalFile() && destination.isLocalFile() ) {
+        item->convertProcess->clearArguments();
+
+        *(item->convertProcess) << "cp";
+        *(item->convertProcess) << source.path();
+        *(item->convertProcess) << destination.path();
+
+        logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
+
+        item->convertProcess->setPriority( config->data.general.priority );
+        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    }
+    else {
+        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, SIGNAL(percent(KIO::Job*,unsigned long)),
+                this, SLOT(moveProgress(KIO::Job*,unsigned long))
+                );
+        connect( item->moveJob, SIGNAL(result(KIO::Job*)),
+                this, SLOT(moveFinished(KIO::Job*))
+                );
+    }
 }
 
 void Convert::executeNextStep( ConvertItem* item )
@@ -1015,6 +1066,46 @@ void Convert::processExit( KProcess* proc )
                     emit rippingFinished( (*item)->fileListItem->device );
                 }
             }
+            if( (*item)->state == ConvertItem::get ) {
+                if( proc->signalled() ) {
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else if( !proc->normalExit() ) {
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("Got file") );
+
+                    // if file is remote or the tag reding failed previously, read the tags now
+                    if( (*item)->fileListItem->tags == 0 ) {
+                        (*item)->fileListItem->tags = tagEngine->readTags( (*item)->tempInFile->name() );
+                    }
+
+                    emit countTime( (*item)->getTime );
+                }
+            }
+            if( (*item)->state == ConvertItem::get_correction ) {
+                if( proc->signalled() ) {
+                    emit uncountTime( (*item)->getTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else if( !proc->normalExit() ) {
+                    emit uncountTime( (*item)->getTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("Got file") );
+                    emit countTime( (*item)->getCorrectionTime );
+                }
+            }
             if( (*item)->state == ConvertItem::decode ) {
                 if( proc->signalled() ) {
                     emit uncountTime( (*item)->getTime );
@@ -1066,6 +1157,62 @@ void Convert::processExit( KProcess* proc )
                     emit countTime( (*item)->encodeTime );
                 }
             }
+            if( (*item)->state == ConvertItem::put ) {
+                if( proc->signalled() ) {
+                    logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                if( !proc->normalExit() ) {
+                    logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("File moved") );
+                }
+            }
+            if( (*item)->state == ConvertItem::put_correction ) {
+                if( proc->signalled() ) {
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, 1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                if( !proc->normalExit() ) {
+                    emit uncountTime( (*item)->getTime );
+                    emit uncountTime( (*item)->getCorrectionTime );
+                    emit uncountTime( (*item)->ripTime );
+                    emit uncountTime( (*item)->decodeTime );
+                    emit uncountTime( (*item)->encodeTime );
+                    emit uncountTime( (*item)->replaygainTime );
+                    remove( *item, -1 );
+                    updateProgressIndicator();
+                    return;
+                }
+                else {
+                    logger->log( (*item)->logID, " " + i18n("File moved") );
+                }
+            }
             if( (*item)->state == ConvertItem::replaygain ) {
                 if( proc->signalled() ) {
                     emit uncountTime( (*item)->getTime );
@@ -1260,6 +1407,7 @@ void Convert::stop( FileListItem* item )
             else if( (*stopItem)->moveJob != 0 ) {
                 //kdDebug() << "Killing file copy..." << endl;
                 // FIXME crashes sometimes - should be fixed by SIGKILL
+                // FIXME crash if file_copy was stealthed
                 logger->log( (*stopItem)->logID, i18n("Killing process ...") );
                 (*stopItem)->moveJob->kill( false );
             }
@@ -1352,16 +1500,38 @@ void Convert::updateProgressIndicator()
             (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Getting correction file")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
         }
         else if( (*it)->state == ConvertItem::rip ) {
-            time += (*it)->ripTime * (*it)->percent / 100;
-            (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Ripping")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            RipperPlugin* plugin = config->getCurrentRipper();
+            if( plugin != 0 && plugin->rip.output.isEmpty() ) {
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Ripping")+"... "+i18n("State")+": "+i18n("Unknown") );
+            }
+            else {
+                time += (*it)->ripTime * (*it)->percent / 100;
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Ripping")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            }
         }
         else if( (*it)->state == ConvertItem::decode ) {
-            time += (*it)->decodeTime * (*it)->percent / 100;
-            (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Decoding")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            ConvertPlugin* plugin = config->decoderForFormat( (*it)->fileListItem->mimeType );
+            if( plugin == 0 || plugin->dec.output.isEmpty() ) {
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Decoding")+"... "+i18n("State")+": "+i18n("Unknown") );
+            }
+            else {
+                time += (*it)->decodeTime * (*it)->percent / 100;
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Decoding")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            }
         }
         else if( (*it)->state == ConvertItem::encode ) {
-            time += (*it)->encodeTime * (*it)->percent / 100;
-            (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Encoding")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            ConvertPlugin* plugin = config->encoderForFormat( (*it)->fileListItem->options.encodingOptions.sFormat );
+            QString outputPattern;
+            if( plugin != 0 && (*it)->fileListItem->options.encodingOptions.sQualityMode == i18n("Quality") ) outputPattern = plugin->enc.lossy.quality.output;
+            else if( plugin != 0 && (*it)->fileListItem->options.encodingOptions.sQualityMode == i18n("Bitrate") && (*it)->fileListItem->options.encodingOptions.sBitrateMode == "cbr" ) outputPattern = plugin->enc.lossy.bitrate.cbr.output;
+            else if( plugin != 0 && (*it)->fileListItem->options.encodingOptions.sQualityMode == i18n("Bitrate") && (*it)->fileListItem->options.encodingOptions.sBitrateMode == "abr" ) outputPattern = plugin->enc.lossy.bitrate.abr.output;
+            if( outputPattern.isEmpty() ) {
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Encoding")+"... "+i18n("State")+": "+i18n("Unknown") );
+            }
+            else {
+                time += (*it)->encodeTime * (*it)->percent / 100;
+                (*it)->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Encoding")+"... "+QString().sprintf("%02i %%",(*it)->percent) );
+            }
         }
         else if( (*it)->state == ConvertItem::replaygain ) {
             time += (*it)->replaygainTime * (*it)->percent / 100;
