@@ -256,25 +256,25 @@ bool FileList::acceptDrag( QDropEvent* e ) const
 void FileList::slotDropped( QDropEvent* e, QListViewItem*, QListViewItem* itemAfter )
 {
     QString file;
-    QStringList list;
+    KURL::List list;
     QStringList files;
-    if( KURLDrag::decodeLocalFiles( e, list ) ) // TODO local?
+    if( KURLDrag::decode( e, list ) ) // TODO local?
     {
         save( true );
-        for( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
+        for( KURL::List::Iterator it = list.begin(); it != list.end(); ++it )
         {
             // TODO verify the files (necessary when multiple files are being dropped)
             // TODO implement cdda:/
-            file = QDir::convertSeparators( *it ); // TODO implement that in the url/file dialog, too?
+            file = QDir::convertSeparators( (*it).url() ); // TODO implement that in the url/file dialog, too?
             QFileInfo fileInfo( file );
-            if( fileInfo.isFile() )
-            {
-                files.append( file );
-            }
-            else if( fileInfo.isDir() )
+            if( fileInfo.isDir() )
             {
                 addDir( file );
             }
+            else
+            {
+                files.append( file );
+            }
         }
         addFiles( files, (FileListItem*)itemAfter, true );
         save( true );
@@ -359,7 +359,7 @@ void FileList::stopSelectedItems()
     }
 }
 
-int FileList::listDir( const QString& directory, bool fast, int count )
+int FileList::listDir( const QString& directory, QStringList filter, bool fast, int count )
 { // NOTE speed up?
     QDir dir( directory );
     dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoSymLinks | QDir::Readable );
@@ -371,21 +371,40 @@ int FileList::listDir( const QString& directory, bool fast, int count )
         QFileInfo fileInfo( directory + "/" + *it );
         if( fast ) {
             if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, fast, count );
+                count = listDir( directory + "/" + *it, filter, fast, count );
             }
             else {
-                count++;
-                pScanStatus->setTotalSteps( count );
+                for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
+                    if( (*it).endsWith("."+(*jt)) ) {
+                        count++;
+                        pScanStatus->setTotalSteps( count );
+                        break;
+                    }
+                }
+                if( filter.first() == "" ) {
+                    count++;
+                    pScanStatus->setTotalSteps( count );
+                }
             }
         }
         else {
             if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, fast, count );
+                count = listDir( directory + "/" + *it, filter, fast, count );
             }
             else {
-                addFiles( directory + "/" + *it );
-                count++;
-                pScanStatus->setProgress( count );
+                for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
+                    if( (*it).endsWith("."+(*jt)) ) {
+                        addFiles( directory + "/" + *it );
+                        count++;
+                        pScanStatus->setProgress( count );
+                        break;
+                    }
+                }
+                if( filter.first() == "" ) {
+                    addFiles( directory + "/" + *it );
+                    count++;
+                    pScanStatus->setProgress( count );
+                }
             }
         }
     }
@@ -530,8 +549,17 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
             filePathName = *it;
             newItem->fileName = filePathName.right( filePathName.length() - filePathName.findRev("/") - 1 );
             newItem->fileFormat = newItem->fileName.right( newItem->fileName.length() - newItem->fileName.findRev(".") - 1 );
-            newItem->mimeType = KMimeType::findByURL( "file:///" + newItem->fileName )->name(); // NOTE http will not work with KMimeType, but we don't access the file anyway
+            // NOTE http will not work with KMimeType - this just works
+            if( filePathName.startsWith("http://") ) {
+                newItem->mimeType = KMimeType::findByURL( "file:///" + newItem->fileName )->name();
+            }
+            else {
+                newItem->mimeType = KMimeType::findByURL( filePathName )->name();
+            }
             // check whether the mime type has a decoder registered
+            if( newItem->mimeType == "" ) {
+                newItem->mimeType = newItem->fileFormat.lower();
+            }
             if( !config->acceptFile( newItem->mimeType ) ) {
                 delete newItem;
                 continue;
@@ -550,15 +578,15 @@ void FileList::addFiles( QStringList fileList, FileListItem* after, bool enabled
     emit fileCountChanged( childCount() );
 }
 
-void FileList::addDir( const QString& directory )
+void FileList::addDir( const QString& directory, const QStringList& filter )
 {
     pScanStatus->setProgress( 0 );
     pScanStatus->setTotalSteps( 0 );
     pScanStatus->show(); // show the status while scanning the directories
     kapp->processEvents();
 
-    int count = listDir( directory, true );
-    listDir( directory );
+    int count = listDir( directory, filter, true );
+    listDir( directory, filter );
 
     pScanStatus->hide(); // hide the status bar, when the scan is done
 }
