@@ -11,7 +11,7 @@
 static const char description[] =
     I18N_NOOP("soundKonverter is a frontend to various sound en- and decoding programs.");
 
-static const char version[] = "0.3.1";
+static const char version[] = "0.3.6";
 
 static KCmdLineOptions options[] =
 {
@@ -31,8 +31,8 @@ static KCmdLineOptions options[] =
 int main(int argc, char **argv)
 {
     KAboutData about("soundkonverter", I18N_NOOP("soundKonverter"), version, description,
-        KAboutData::License_GPL, "(C) 2007 Daniel Faust", 0, 0, "daniel@kaligames.de");
-    about.addAuthor( "Daniel Faust", 0, "daniel@kaligames.de", "http://kaligames.de" );
+        KAboutData::License_GPL, "(C) 2007 Daniel Faust", 0, 0, "hessijames@gmail.com");
+    about.addAuthor( "Daniel Faust", 0, "hessijames@gmail.com" );
     about.addCredit( "David Vignoni", "Nuvola icon theme", 0, "http://www.icon-king.com" );
     about.addCredit( "Scott Wheeler", "TagLib", "wheeler@kde.org", "http://ktown.kde.org/~wheeler" );
     about.addCredit( "Amarok developers", "Amarok", 0, "http://amarok.kde.org" );
