@@ -388,6 +388,7 @@ void OutputDirectory::modeChangedSlot( int mode )
     else */
     if( (Mode)mode == MetaData ) {
         pClear->setEnabled( true );
+        if( config->data.general.metaDataOutputDirectory.isEmpty() ) config->data.general.metaDataOutputDirectory = QDir::homeDirPath() + "/soundKonverter/%b/%d - %n - %a - %t";
         lDir->setText( config->data.general.metaDataOutputDirectory );
         lDir->setEnabled( true );
         lDir->setReadOnly( false );
@@ -415,6 +416,7 @@ void OutputDirectory::modeChangedSlot( int mode )
     }
     else if( (Mode)mode == Specify ) {
         pClear->setEnabled( true );
+        if( config->data.general.specifyOutputDirectory.isEmpty() ) config->data.general.specifyOutputDirectory = QDir::homeDirPath() + "/soundKonverter";
         lDir->setText( config->data.general.specifyOutputDirectory );
         lDir->setEnabled( true );
         lDir->setReadOnly( false );
@@ -428,6 +430,7 @@ void OutputDirectory::modeChangedSlot( int mode )
     }
     else if( (Mode)mode == CopyStructure ) {
         pClear->setEnabled( true );
+        if( config->data.general.copyStructureOutputDirectory.isEmpty() ) config->data.general.copyStructureOutputDirectory = QDir::homeDirPath() + "/soundKonverter";
         lDir->setText( config->data.general.copyStructureOutputDirectory );
         lDir->setEnabled( true );
         lDir->setReadOnly( false );
