@@ -495,7 +495,7 @@ void ReplayGainFileList::contentsDropEvent( QDropEvent *e )
     }
 }
 
-int ReplayGainFileList::listDir( const QString& directory, bool fast, int count )
+int ReplayGainFileList::listDir( const QString& directory, QStringList filter, bool fast, int count )
 { // NOTE speed up?
     QDir dir( directory );
     dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoSymLinks | QDir::Readable );
@@ -507,21 +507,40 @@ int ReplayGainFileList::listDir( const QString& directory, bool fast, int count
         QFileInfo fileInfo( directory + "/" + *it );
         if( fast ) {
             if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, fast, count );
+                count = listDir( directory + "/" + *it, filter, fast, count );
             }
             else {
-                count++;
-                pScanStatus->setTotalSteps( count );
+                for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
+                    if( (*it).endsWith("."+(*jt)) ) {
+                        count++;
+                        pScanStatus->setTotalSteps( count );
+                        break;
+                    }
+                }
+                if( filter.first() == "" ) {
+                    count++;
+                    pScanStatus->setTotalSteps( count );
+                }
             }
         }
         else {
             if( fileInfo.isDir() ) {
-                count = listDir( directory + "/" + *it, fast, count );
+                count = listDir( directory + "/" + *it, filter, fast, count );
             }
             else {
-                addFile( directory + "/" + *it );
-                count++;
-                pScanStatus->setProgress( count );
+                for( QStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
+                    if( (*it).endsWith("."+(*jt)) ) {
+                        addFile( directory + "/" + *it );
+                        count++;
+                        pScanStatus->setProgress( count );
+                        break;
+                    }
+                }
+                if( filter.first() == "" ) {
+                    addFile( directory + "/" + *it );
+                    count++;
+                    pScanStatus->setProgress( count );
+                }
             }
         }
     }
@@ -748,15 +767,15 @@ void ReplayGainFileList::addFile( const QString& file )
     }
 }
 
-void ReplayGainFileList::addDir( const QString& directory )
+void ReplayGainFileList::addDir( const QString& directory, const QStringList& filter )
 {
     pScanStatus->setProgress( 0 );
     pScanStatus->setTotalSteps( 0 );
     pScanStatus->show(); // show the status while scanning the directories
     kapp->processEvents();
 
-    int count = listDir( directory, true );
-    listDir( directory );
+    int count = listDir( directory, filter, true );
+    listDir( directory, filter );
 
     pScanStatus->hide(); // hide the status bar, when the scan is done
 }
@@ -924,6 +943,8 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
     QStringList fileList;
     bool force = false;
     if( mode & ReplayGainFileListItem::force ) force = true;
+    QString album_gain = "";
+    bool skip = true;
 
     timeCount = 0;
     file = 0;
@@ -942,13 +963,28 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
             fileList += sub_item->filePathName;
             files++;
             timeCount += sub_item->time;
+
+            QString current_gain = sub_item->text( columnByName(i18n("Album")) );
+            if( album_gain == "" ) album_gain = current_gain;
+            else if( album_gain != current_gain ) skip = false;
         }
 
-        if( force ) {
-            replayGain->apply( fileList, item->mimeType, process, logID, ReplayGain::Mode(ReplayGain::calc_album|ReplayGain::force) );
+        if( !skip || album_gain == i18n("Unknown") ) {
+            if( force ) {
+                replayGain->apply( fileList, item->mimeType, process, logID, ReplayGain::Mode(ReplayGain::calc_album|ReplayGain::force) );
+            }
+            else {
+                replayGain->apply( fileList, item->mimeType, process, logID );
+            }
         }
         else {
-            replayGain->apply( fileList, item->mimeType, process, logID );
+            item->addingReplayGain = false;
+            item->repaint();
+            for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
+                sub_item->addingReplayGain = false;
+                sub_item->repaint();
+            }
+            processNextFile();
         }
     }
     else {
