@@ -3,6 +3,7 @@
 #include "logger.h"
 #include "combobutton.h"
 #include "config.h"
+#include "dirdialog.h"
 
 #include <qlayout.h>
 #include <qstringlist.h>
@@ -67,8 +68,8 @@ ReplayGainScanner::ReplayGainScanner( TagEngine* _tagEngine, Config* _config, Lo
     connect( this, SIGNAL(addFile(const QString&)),
                lList, SLOT(addFile(const QString&))
              );
-    connect( this, SIGNAL(addDir(const QString&)),
-               lList, SLOT(addDir(const QString&))
+    connect( this, SIGNAL(addDir(const QString&,const QStringList&)),
+               lList, SLOT(addDir(const QString&,const QStringList&))
              );
     connect( this, SIGNAL(calcAllReplayGain(bool)),
                lList, SLOT(calcAllReplayGain(bool))
@@ -147,7 +148,7 @@ void ReplayGainScanner::addClicked( int index )
 
 void ReplayGainScanner::showFileDialog()
 {
-    KFileDialog* dialog = new KFileDialog( ":file_open", "*", this, i18n("Choose files!"), true );
+    KFileDialog* dialog = new KFileDialog( ":file_open", config->replayGainFilter(), this, i18n("Choose files!"), true );
     dialog->setMode ( KFile::Files | KFile::ExistingOnly );
     if( dialog->exec() == KDialog::Accepted ) {
         QStringList urls = dialog->selectedURLs().toStringList();
@@ -159,11 +160,21 @@ void ReplayGainScanner::showFileDialog()
 
 void ReplayGainScanner::showDirDialog()
 {
-    QString directory = KFileDialog::getExistingDirectory( ":file_open", this, i18n("Choose a directory!") );
-    if( directory != NULL )
-    {
-        emit addDir( directory );
+//     QString directory = KFileDialog::getExistingDirectory( ":file_open", this, i18n("Choose a directory!") );
+//     if( directory != NULL )
+//     {
+//         emit addDir( directory );
+//     }
+
+    DirDialog *dialog = new DirDialog( config, DirDialog::ReplayGain, this, "DirDialog" );
+
+    Q_CHECK_PTR( dialog );
+
+    if( dialog->exec() ) {
+        emit addDir( dialog->directory, dialog->selectedFileTypes );
     }
+
+    delete dialog;
 }
 
 void ReplayGainScanner::addFiles( QStringList files )
