@@ -17,6 +17,7 @@
 #include "cuesheeteditor.h"
 // ### #include "aboutplugins.h" delayed to a future soundkonverter version
 #include "optionsrequester.h"
+#include "dirdialog.h"
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -38,6 +39,8 @@
 #include <qlayout.h>
 #include <qprogressbar.h>
 #include <qfont.h>
+#include <qhbox.h>
+#include <qeventloop.h>
 
 // TODO stop all processes on exit / clean tmp up
 
@@ -305,7 +308,7 @@ bool soundKonverter::queryClose()
     config->removeProfile( i18n("Last used") );
     config->addProfile( i18n("Last used"), options->getCurrentOptions() );
 
-    config->write();
+    config->write( false );
 
     convert->cleanUp();
     logger->cleanUp();
@@ -494,11 +497,21 @@ void soundKonverter::showFileDialog()
 
 void soundKonverter::showDirDialog()
 {
-    QString directory = KFileDialog::getExistingDirectory( ":file_open", this, i18n("Choose a directory") );
-    if( !directory.isEmpty() )
-    {
-        fileList->addDir( directory );
+//     QString directory = KFileDialog::getExistingDirectory( ":file_open", this, i18n("Choose a directory") );
+//     if( !directory.isEmpty() )
+//     {
+//         fileList->addDir( directory );
+//     }
+
+    DirDialog *dialog = new DirDialog( config, DirDialog::Convert, this, "DirDialog" );
+
+    Q_CHECK_PTR( dialog );
+
+    if( dialog->exec() ) {
+        fileList->addDir( dialog->directory, dialog->selectedFileTypes );
     }
+
+    delete dialog;
 }
 
 void soundKonverter::showCdDialog( bool intern )
@@ -533,8 +546,8 @@ void soundKonverter::showCdDialog( bool intern )
 
         dialog->exec();
 
-//         disconnect( dialog, SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
-        disconnect( dialog, SIGNAL(addFiles(QStringList)), 0, 0 );
+        disconnect( dialog, SIGNAL(setCurrentOptions(const ConversionOptions&)), 0, 0 );
+//         disconnect( dialog, SIGNAL(addFiles(QStringList)), 0, 0 );
 
         delete dialog;
     }
@@ -564,6 +577,8 @@ void soundKonverter::showCdDialog( bool intern )
         device = "";
     }
 
+    kapp->eventLoop()->exitLoop();
+
     // create a new CDOpener object for letting the user add some tracks from a CD
     CDOpener *dialog = new CDOpener( config, cdManager, tagEngine, device, this, "CDOpener" );
 
@@ -571,24 +586,28 @@ void soundKonverter::showCdDialog( bool intern )
 
     Q_CHECK_PTR( dialog );
 
-    connect( dialog, SIGNAL(addTracks(const QString&,QValueList<int>)),
-               fileList, SLOT(addTracks(const QString&,QValueList<int>))
-             );
-    connect( dialog, SIGNAL(addDisc(const QString&)),
-               fileList, SLOT(addDisc(const QString&))
-             );
-    /*connect( dialog, SIGNAL(openCuesheetEditor(const QString&)),
-               this, SLOT(openCuesheetEditor(const QString&))
-             );*/
+    if( !dialog->noCD )
+    {
+        connect( dialog, SIGNAL(addTracks(const QString&,QValueList<int>)),
+                fileList, SLOT(addTracks(const QString&,QValueList<int>))
+                );
+        connect( dialog, SIGNAL(addDisc(const QString&)),
+                fileList, SLOT(addDisc(const QString&))
+                );
+        /*connect( dialog, SIGNAL(openCuesheetEditor(const QString&)),
+                this, SLOT(openCuesheetEditor(const QString&))
+                );*/
 
-    dialog->exec();
-
-    disconnect( dialog, SIGNAL(addTracks(const QString&,QValueList<int>)), 0, 0 );
-    disconnect( dialog, SIGNAL(addDisc(const QString&)), 0, 0 );
-    //disconnect( dialog, SIGNAL(openCuesheetEditor(const QString&)), 0, 0 );
+        dialog->exec();
 
+        disconnect( dialog, SIGNAL(addTracks(const QString&,QValueList<int>)), 0, 0 );
+        disconnect( dialog, SIGNAL(addDisc(const QString&)), 0, 0 );
+        //disconnect( dialog, SIGNAL(openCuesheetEditor(const QString&)), 0, 0 );
+    }
     delete dialog;
 
+    kapp->eventLoop()->enterLoop();
+
     options->setCurrentOptions( conversionOptions );
 }
 
@@ -717,7 +736,6 @@ void soundKonverter::showToolbar()
         toolBar()->hide();
         config->data.general.showToolBar = false;
     }
-//     config->write();
 }
 
 void soundKonverter::editToolbar()
